# cwb-bus

Package aimed at facilitating the use of the open data from Curitiba\'s public transport system

Developed by [Angelin01](https://github.com/Angelin01/), [killertux](https://github.com/killertux/) and [Kabbah](https://github.com/Kabbah/).
